# Streaming process mining with `pyBeamline`

[![PyPI version](https://badge.fury.io/py/pybeamline.svg)](https://badge.fury.io/py/pybeamline)

`pyBeamline` is a Python version of Beamline. While the same set of ideas and principles of Beamline have been ported into `pyBeamline`, the underlying goal and technology is very different.

pyBeamline is based on ReactiveX and its Python binding RxPY. RxPY is a library for composing asynchronous and event-based programs using observable sequences and pipable query operators in Python. Using pyBeamline it is possible to inject process mining operators into the computation.

For a complete documentation of the library see https://www.beamline.cloud/pybeamline/. To install the library use:
```console
pip install pybeamline
```
A complete Jupyter notebook presenting all techniques available is available at https://github.com/beamline/pybeamline/blob/master/tutorial.ipynb.

<a href="https://colab.research.google.com/github/beamline/pybeamline/blob/master/tutorial.ipynb" target="_blank">
<img alt="Open In Colab" src="https://colab.research.google.com/assets/colab-badge.svg">
</img></a>
